
Project documentation
=====================
Contents:

.. contents:: Table of Contents

.. toctree::
   :maxdepth: 2

   index
   recipes
   cheatsheet
   creating_files
   creating_images
   creating_pdf
   creating_docx
   creating_odt
   creating_archives
   factories
   customisation
   cli
   security
   contributor_guidelines
   code_of_conduct
   changelog
   package
